## This is a mini deep learning framework created by Chongyu

## Features
+ Define Dynamic Computing Graph
+ Define Neural Network Operater
+ Define Linear,Sigmoid,L2_loss
+ Auto-diff Computing
+ Auto-Feedfoward and Backward

## Remain
+ Classification
+ Cross-Entropy
+ CNN,RNN

## Connection

wechat: Obliviatecy
Mail: zcyu_eternal@foxmail.com
